package com.fs.store.service;

import com.fs.store.domain.FsQuestions;
import com.fs.store.param.FsQuestionsListUParam;
import com.fs.store.vo.FsQuestionsListUVO;

import java.util.List;

/**
 * 问答专区Service接口
 *
 * @author fs
 * @date 2023-10-23
 */
public interface IFsQuestionsService
{
    /**
     * 查询问答专区
     *
     * @param id 问答专区主键
     * @return 问答专区
     */
    public FsQuestions selectFsQuestionsById(Long id);

    /**
     * 查询问答专区列表
     *
     * @param fsQuestions 问答专区
     * @return 问答专区集合
     */
    public List<FsQuestions> selectFsQuestionsList(FsQuestions fsQuestions);

    /**
     * 新增问答专区
     *
     * @param fsQuestions 问答专区
     * @return 结果
     */
    public int insertFsQuestions(FsQuestions fsQuestions);

    /**
     * 修改问答专区
     *
     * @param fsQuestions 问答专区
     * @return 结果
     */
    public int updateFsQuestions(FsQuestions fsQuestions);

    /**
     * 批量删除问答专区
     *
     * @param ids 需要删除的问答专区主键集合
     * @return 结果
     */
    public int deleteFsQuestionsByIds(Long[] ids);

    /**
     * 删除问答专区信息
     *
     * @param id 问答专区主键
     * @return 结果
     */
    public int deleteFsQuestionsById(Long id);

    String importData(List<FsQuestions> list);

    List<FsQuestionsListUVO> selectFsQuestionsListUVO(FsQuestionsListUParam param);
}
